==> plugin-security-2.0.1-sources.jar: com/ohaotian/plugin/security/entity/MenuInfo.java <==
package com.ohaotian.plugin.security.entity;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/**
 * 菜单
 *
 * @author liubq
 */
public class MenuInfo implements Comparable<MenuInfo>, Serializable {
    private static final long serialVersionUID = 6474583696268886768L;

    private Long menuId;

    private Long parentId;

    private Integer deep;

    private Integer order;

    private String menuName;

    private String menuCode;

    private String icon;

    private String contentPath;

    private String domain;

    private String url;

    private Integer isVue;

    public Integer getIsVue() {
        return isVue;
    }

    public void setIsVue(Integer isVue) {
        this.isVue = isVue;
    }

    private List<MenuInfo> subMenus = new ArrayList<MenuInfo>();

    public Long getMenuId() {
        return menuId;
    }

    public void setMenuId(Long menuId) {
        this.menuId = menuId;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public Integer getDeep() {
        return deep;
    }

    public void setDeep(Integer deep) {
        this.deep = deep;
    }

    public Integer getOrder() {
        return order;
    }

    public void setOrder(Integer order) {
        this.order = order;
    }

    public String getMenuName() {
        return menuName;
    }

    public void setMenuName(String menuName) {
        this.menuName = menuName;
    }

    public String getMenuCode() {
        return menuCode;
    }

    public void setMenuCode(String menuCode) {
        this.menuCode = menuCode;
    }

    public String getIcon() {
        return icon;
    }

    public void setIcon(String icon) {
        this.icon = icon;
    }

    public String getContentPath() {
        return contentPath;
    }

    public void setContentPath(String contentPath) {
        this.contentPath = contentPath;
    }

    public String getDomain() {
        return domain;
    }

    public void setDomain(String domain) {
        this.domain = domain;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    /**
     * @return the subMenus
     */
    public List<MenuInfo> getSubMenus() {
        return subMenus;
    }

    /**
     * @param subMenus the subMenus to set
     */
    public void setSubMenus(List<MenuInfo> subMenus) {
        this.subMenus = subMenus;
    }


    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        MenuInfo menuInfo = (MenuInfo) o;

        if (!menuId.equals(menuInfo.menuId)) return false;
        return url != null ? url.equals(menuInfo.url) : menuInfo.url == null;
    }

    @Override
    public int hashCode() {
        int result = menuId != null ? menuId.hashCode() : 0;
        result = 31 * result + (url != null ? url.hashCode() : 0);
        return result;
    }

    @Override
    public int compareTo(MenuInfo o) {
        return this.getOrder().compareTo(o.getOrder());
    }


}

==> plugin-security-2.0.7-20200507.075247-2-sources.jar: com/ohaotian/plugin/security/entity/MenuInfo.java <==
package com.ohaotian.plugin.security.entity;

import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.serializer.ToStringSerializer;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/**
 * 菜单
 *
 * @author liubq
 */
public class MenuInfo implements Comparable<MenuInfo>, Serializable {
    private static final long serialVersionUID = 6474583696268886768L;

    @JSONField(serializeUsing = ToStringSerializer.class)
    private Long menuId;

    @JSONField(serializeUsing = ToStringSerializer.class)
    private Long parentId;

    private Integer deep;

    private Integer order;

    private String menuName;

    private String menuCode;

    private String icon;

    private String contentPath;

    private String domain;

    private String url;

    private Integer isVue;

    public Integer getIsVue() {
        return isVue;
    }

    public void setIsVue(Integer isVue) {
        this.isVue = isVue;
    }

    private List<MenuInfo> subMenus = new ArrayList<MenuInfo>();

    public Long getMenuId() {
        return menuId;
    }

    public void setMenuId(Long menuId) {
        this.menuId = menuId;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public Integer getDeep() {
        return deep;
    }

    public void setDeep(Integer deep) {
        this.deep = deep;
    }

    public Integer getOrder() {
        return order;
    }

    public void setOrder(Integer order) {
        this.order = order;
    }

    public String getMenuName() {
        return menuName;
    }

    public void setMenuName(String menuName) {
        this.menuName = menuName;
    }

    public String getMenuCode() {
        return menuCode;
    }

    public void setMenuCode(String menuCode) {
        this.menuCode = menuCode;
    }

    public String getIcon() {
        return icon;
    }

    public void setIcon(String icon) {
        this.icon = icon;
    }

    public String getContentPath() {
        return contentPath;
    }

    public void setContentPath(String contentPath) {
        this.contentPath = contentPath;
    }

    public String getDomain() {
        return domain;
    }

    public void setDomain(String domain) {
        this.domain = domain;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    /**
     * @return the subMenus
     */
    public List<MenuInfo> getSubMenus() {
        return subMenus;
    }

    /**
     * @param subMenus the subMenus to set
     */
    public void setSubMenus(List<MenuInfo> subMenus) {
        this.subMenus = subMenus;
    }


    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        MenuInfo menuInfo = (MenuInfo) o;

        if (!menuId.equals(menuInfo.menuId)) return false;
        return url != null ? url.equals(menuInfo.url) : menuInfo.url == null;
    }

    @Override
    public int hashCode() {
        int result = menuId != null ? menuId.hashCode() : 0;
        result = 31 * result + (url != null ? url.hashCode() : 0);
        return result;
    }

    @Override
    public int compareTo(MenuInfo o) {
        return this.getOrder().compareTo(o.getOrder());
    }


}
